@@ -345,7 +345,7 @@ mnt()
     fi
 
     [ "$VERBOSE" = 1 ] && echo "$PRG: Mounting $boot..."
-    mount -t "$fstype" -o codepage=437,iocharset=iso8859-1,rw,noexec,umask=077$loop "$boot" "$TMP/bootstrap.$$"
+    mount -t "$fstype" -o codepage=437,rw,noexec,umask=077$loop "$boot" "$TMP/bootstrap.$$"
     if [ $? != 0 ] ; then
 	echo 1>&2 "$PRG: An error occured mounting $boot"
 	return 1
